import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {areaRecord} from "@/api/demo/cascader"; // 引入开关组件
type CheckedType = boolean | string | number;

export const dictionColumns: BasicColumn[] = [
  {
    title: '命名字典',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '命名字典路径',
    dataIndex: 'path',
    width: 120,
  },
]
export const removeColumns: BasicColumn[] = [
  {
    title: '域',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '命名字典',
    dataIndex: 'dicName',
    width: 120,
  },
  {
    title: '命名字典路径',
    dataIndex: 'path',
    width: 120,
  },
]
export const columnsTwo: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 120,
  },
]
export const columns: BasicColumn[] = [
  {
    title: '域名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '路径',
    dataIndex: 'valueOne',
    width: 120,
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '域名称',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入域名称',
    },
  },

];


export const formSchema: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '关联元模型',
    rules: [
      {
        required: true,
        message: '请输入路径',
      },
    ],
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
]
export const formSchemaManage: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    rules: [
      {
        required: true,
        message: '请输入路径',
      },
    ],
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '域名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入域名称',
      },
    ],
  },
  {
    field: 'type',
    label: '类型',
    component: 'Input',
    defaultValue:'域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]



/**详情表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '域名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'短编号',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '父域',
    component: 'Input',
    defaultValue: '字符型',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文全称',
    },
  },
  {
    field: 'valueThree',
    label: '字段示例',
    component: 'Input',
    defaultValue:'会员号/品种代码',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文简称',
    },
  },
  {
    field: 'valueFour',
    label: '数据类型',
    component: 'Input',
    defaultValue:'varchar',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueFive',
    label: '传统数据库数据类型',
    component: 'Input',
    defaultValue:'varchar',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueSix',
    label: '长度',
    component: 'Input',
    defaultValue:'10',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueSeven',
    label: '精度',
    component: 'Input',
    defaultValue:'-',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
];
export const detailSchema2: FormSchema[] = [
  {
    field: 'valueOne',
    label: '域名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'短编号',
    componentProps: {
      placeholder: '请输入域名称',
    },
  },
  {
    field: 'valueTwo',
    label: '父域',
    component: 'Select',
    defaultValue: '字符型',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '',
      options: [
        { label: '字符型', value: '字符型' },
      ],
    },
  },
  {
    field: 'valueThree',
    label: '字段示例',
    component: 'Input',
    defaultValue:'会员号/品种代码',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入字段示例',
    },
  },
  {
    field: 'valueFour',
    label: '数据类型',
    component: 'Select',
    defaultValue: 'varchar',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '',
      options: [
        { label: 'varchar', value: 'varchar' },
        { label: 'int', value: 'int' },
      ],
    },
  },
  {
    field: 'valueFive',
    label: '传统数据库类型',
    component: 'Input',
    defaultValue:'varchar',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入传统数据库类型',
    },
  },
  {
    field: 'valueSix',
    label: '长度',
    component: 'Input',
    defaultValue:'10',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入长度',
    },
  },
  {
    field: 'valueSeven',
    label: '精度',
    component: 'Input',
    defaultValue:'-',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入精度',
    },
  },
];
export const detailSchema3: FormSchema[] = [
  {
    field: '',
    label: '域属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '关联域',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期类',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },


];
export const detailSchema4: FormSchema[] = [
  {
    field: 'valueOne',
    label: '域名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期类',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      disabled: true,
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '父域',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期时间型',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueThree',
    label: '字段示例',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'成交日期',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueFour',
    label: '数据类型',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'date',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueFive',
    label: '传统数据库类型',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'date',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueSix',
    label: '长度',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'123',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueSeven',
    label: '精度',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
];
export const detailSchema5: FormSchema[] = [
  {
    field: '',
    label: '域属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    component: 'Cascader',
    label: '关联域',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
];
export const formSchemaImport: any = [
  {
    field: 'path',
    label: '选择文件地址',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
]
